;; Generated package description from firefox-javascript-repl.el  -*- no-byte-compile: t -*-
(define-package "firefox-javascript-repl" "0.9.3" "Jack into Firefox" '((emacs "26.1")) :commit "a531550c7b3a9e6c66758a3508afe40750ca689a" :url "https://elpa.gnu.org/packages/firefox-javascript-repl.html" :authors '(("Thomas Fitzsimmons" . "fitzsim@fitzsim.org")) :maintainer '("Thomas Fitzsimmons" . "fitzsim@fitzsim.org"))
